#
# spec file for package qt6-svg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define real_version 6.8.2
%define short_version 6.8
%define tar_name qtsvg-everywhere-src
%define tar_suffix %{nil}
#
%global qt6_flavor %{nil}
%if "%{qt6_flavor}" == "docs"
%define pkg_suffix -docs
%endif
#
Name:           qt6-svg%{?pkg_suffix}
Version:        6.8.2
Release:        1.2
Summary:        Classes for rendering and displaying SVG drawings
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{short_version}/%{real_version}%{tar_suffix}/submodules/%{tar_name}-%{real_version}%{tar_suffix}.tar.xz
Source99:       qt6-svg-rpmlintrc
BuildRequires:  pkgconfig
BuildRequires:  qt6-core-private-devel
BuildRequires:  qt6-gui-private-devel
BuildRequires:  qt6-widgets-private-devel
BuildRequires:  cmake(Qt6Core) = %{real_version}
BuildRequires:  cmake(Qt6Gui) = %{real_version}
BuildRequires:  cmake(Qt6Widgets) = %{real_version}
BuildRequires:  pkgconfig(zlib)
# Ignored: only used for building tests
# BuildRequires:  cmake(Qt6Xml)
%if "%{qt6_flavor}" == "docs"
BuildRequires:  qt6-tools
%{qt6_doc_packages}
%endif

%description
The Qt SVG module provides classes for rendering and displaying SVG drawings
in widgets and on other paint devices.

%if !%{qt6_docs_flavor}

%package -n libQt6Svg6
Summary:        Qt 6 Svg library

%description -n libQt6Svg6
The Qt 6 Svg library.

%package -n libQt6SvgWidgets6
Summary:        Qt 6 SVGWidgets library

%description -n libQt6SvgWidgets6
The Qt 6 SvgWidgets library.

%package devel
Summary:        Qt 6 SVG libraries - Development files
Requires:       libQt6Svg6 = %{version}
Requires:       libQt6SvgWidgets6 = %{version}
Requires:       cmake(Qt6Gui) = %{real_version}
Requires:       cmake(Qt6Widgets) = %{real_version}

%description devel
Development files for the Qt 6 SVG libraries.

%package private-devel
Summary:        Non-ABI stable API for the Qt 6 SVG libraries
Requires:       cmake(Qt6Svg) = %{real_version}
Requires:       cmake(Qt6SvgWidgets) = %{real_version}
%requires_eq    qt6-core-private-devel
%requires_eq    qt6-gui-private-devel
%requires_eq    qt6-widgets-private-devel

%description private-devel
This package provides private headers of libQt6Svg that do not have any
ABI or API guarantees.

%endif

%prep
%autosetup -p1 -n %{tar_name}-%{real_version}%{tar_suffix}

%build
%cmake_qt6 \
  -DQT_GENERATE_SBOM:BOOL=FALSE

%{qt6_build}

%install
%{qt6_install}

%if !%{qt6_docs_flavor}

# No private headers for Qt6SvgWidgets
rm %{buildroot}%{_qt6_mkspecsdir}/modules/qt_lib_svgwidgets_private.pri

%ldconfig_scriptlets -n libQt6Svg6
%ldconfig_scriptlets -n libQt6SvgWidgets6

%files -n libQt6Svg6
%license LICENSES/*
%dir %{_qt6_pluginsdir}/iconengines
%dir %{_qt6_pluginsdir}/imageformats
%{_qt6_pluginsdir}/iconengines/libqsvgicon.so
%{_qt6_pluginsdir}/imageformats/libqsvg.so
%{_qt6_libdir}/libQt6Svg.so.*

%files -n libQt6SvgWidgets6
%{_qt6_libdir}/libQt6SvgWidgets.so.*

%files devel
%{_qt6_cmakedir}/Qt6BuildInternals/StandaloneTests/QtSvgTestsConfig.cmake
%{_qt6_cmakedir}/Qt6Gui/*
%{_qt6_cmakedir}/Qt6Svg/
%{_qt6_cmakedir}/Qt6SvgWidgets/
%{_qt6_descriptionsdir}/Svg.json
%{_qt6_descriptionsdir}/SvgWidgets.json
%{_qt6_includedir}/QtSvg/
%{_qt6_includedir}/QtSvgWidgets/
%{_qt6_libdir}/libQt6Svg.prl
%{_qt6_libdir}/libQt6Svg.so
%{_qt6_libdir}/libQt6SvgWidgets.prl
%{_qt6_libdir}/libQt6SvgWidgets.so
%{_qt6_metatypesdir}/qt6svg_*_metatypes.json
%{_qt6_metatypesdir}/qt6svgwidgets_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_svg.pri
%{_qt6_mkspecsdir}/modules/qt_lib_svgwidgets.pri
%{_qt6_pkgconfigdir}/Qt6Svg.pc
%{_qt6_pkgconfigdir}/Qt6SvgWidgets.pc
%exclude %{_qt6_includedir}/QtSvg/%{real_version}/

%files private-devel
%dir %{_qt6_includedir}/QtSvg/
%{_qt6_includedir}/QtSvg/%{real_version}/
%{_qt6_mkspecsdir}/modules/qt_lib_svg_private.pri

%endif

%changelog
* Fri Jan 31 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.8.2
  https://www.qt.io/blog/qt-6.8.2-released
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.1:
  * https://www.qt.io/blog/qt-6.8.1-released
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0:
  * https://www.qt.io/blog/qt-6.8-released
* Sat Sep 28 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.3
  * https://www.qt.io/blog/qt-6.7.3-released
* Wed Jun 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.2:
  * https://www.qt.io/blog/qt-6.7.2-released
* Tue May 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.1:
  * https://www.qt.io/blog/qt-6.7.1-released
* Tue Apr  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0:
  * https://www.qt.io/blog/qt-6.7-released
* Tue Mar 26 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.3:
  * https://www.qt.io/blog/qt-6.6.3-released
* Wed Feb 14 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.2
  * https://www.qt.io/blog/qt-6.6.2-released
* Mon Nov 27 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.1:
  * https://www.qt.io/blog/qt-6.6.1-released
- Drop patches, merged upstream:
  * 0001-fix-nullptr-derefence-with-invalid-SVG.patch
  * 0002-make-sure-we-do-not-load-invalid-SVGs-twice.patch
* Mon Oct 16 2023 Manfred Hollstein <manfred.h@gmx.net>
- Add patches (boo#1216269, QTBUG-117944):
  * 0001-fix-nullptr-derefence-with-invalid-SVG.patch
  * 0002-make-sure-we-do-not-load-invalid-SVGs-twice.patch
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * https://www.qt.io/blog/qt-6.6-released
* Thu Sep 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.3
  * https://www.qt.io/blog/qt-6.5.3-released
* Thu Jul 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.2
  * https://www.qt.io/blog/qt-6.5.2-released-1
* Wed May 24 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.1
  * https://www.qt.io/blog/qt-6.5.1-released
- Drop patch, merged upstream:
  * CVE-2023-32573-qtsvg-6.5.diff
* Thu May 11 2023 Christophe Marin <christophe@krop.fr>
- Add upstream change (boo#1211298, CVE-2023-32573):
  * CVE-2023-32573-qtsvg-6.5.diff
* Mon Apr  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * https://www.qt.io/blog/qt-6.5-lts-released
* Thu Mar 16 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.3:
  * https://www.qt.io/blog/qt-6.4.3-released
* Fri Jan  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.2:
  * https://www.qt.io/blog/qt-6.4.2-released
* Tue Nov 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.1:
  * https://www.qt.io/blog/qt-6.4.1-released
* Thu Sep 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0:
  * https://www.qt.io/blog/qt-6.4-released
* Fri Sep 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0 RC
* Fri Sep  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.2:
  * https://www.qt.io/blog/qt-6.3.2-released
* Fri Jun 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.1:
  * https://www.qt.io/blog/qt-6.3.1-released
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0:
  * https://www.qt.io/blog/qt-6.3-released
* Tue Mar 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0-rc
* Mon Mar 21 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.4
  * https://www.qt.io/blog/qt-6.2.4-released
* Mon Jan 31 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.3:
  * https://www.qt.io/blog/qt-6.2.3-released
* Wed Dec  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.2
  * https://www.qt.io/blog/qt-6.2.2-released
- Make sure all dependencies are present when installing devel
  packages. Qt >= 6.2.2 is much less permissive.
* Tue Oct 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.1
  * https://www.qt.io/blog/qt-6.2.1-released
* Thu Sep 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0:
  * https://www.qt.io/blog/qt-6.2-lts-released
* Sat Sep 25 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc2
* Thu Sep 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc
* Thu Sep  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-beta4
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.3:
  * https://www.qt.io/blog/qt-6.1.3-released
* Fri Jul  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.2. New bugfix release:
  * https://www.qt.io/blog/qt-6.1.2-released
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.1:
  * https://www.qt.io/blog/qt-6.1.1-released
* Thu May  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0:
  * https://www.qt.io/blog/qt-6.1-released
* Fri Apr 23 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-rc.
* Tue Apr 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-beta3.
* Wed Mar 31 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.3
  * https://www.qt.io/blog/qt-6.0.3-released
* Fri Mar 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-beta2
* Tue Mar  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.1.0-beta1
  https://www.qt.io/blog/qt-6.1-beta-released
* Tue Mar  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.2:
  https://www.qt.io/blog/qt-6.0.2-released
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.1
  https://www.qt.io/blog/qt-6.0.1-released
* Wed Dec 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Use a different 'Name' when building the docs flavor.
* Sat Dec 12 2020 Christophe Giboudeaux <christophe@krop.fr>
- Remove a debug line.
* Tue Dec  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0:
  * https://www.qt.io/blog/qt-6.0-released
* Wed Dec  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Qt 6.0.0 RC2
* Wed Nov 25 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0~rc1
* Tue Nov 17 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0~beta5
* Tue Nov 10 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0~beta4
* Tue Oct 20 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0beta1
  https://www.qt.io/blog/qt-6.0-beta-released
* Tue Oct  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0-alpha
  https://www.qt.io/blog/qt-6.0-alpha-released
* Fri May  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add undetected build requirements to the -devel package.
* Fri Jan 31 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add qt6-svg
